@@ -4,6 +4,9 @@ Helpers.py
 A collection of static helper functions for the library.
 """
 
+from typing import Tuple, Optional
+
+from random import randint
 from math import sqrt
 
 def hex_to_int(hex_num: str, word_size: int) -> int:
@@ -45,3 +48,26 @@ def scale_linear(val: int, min_1: int, max_1: int, min_2: int, max_2: int) -> fl
         range_1 = 0.00001
     
     return (val - min_1) / range_1 * (max_2 - min_2) + min_2
+
+def within_bounds(bounds: Optional[Tuple[Tuple[int, int], Tuple[int, int]]], x: int,
+        y: int) -> bool:
+    """
+    Returns True if the given x, y coordinates are contained in the given bounds formatted like
+    ((x1, y1), (x2, y2)). Returns False if the given x, y coordinates are not within the bounds, or
+    if bounds is None.
+    """
+
+    if bounds is None:
+        return False
+    
+    return bounds[0][0] <= x <= bounds[1][0] and bounds[0][1] <= y <= bounds[1][1]
+
+def random_within_bounds(bounds: Tuple[Tuple[int, int], Tuple[int, int]]) -> Tuple[int, int]:
+    """
+    Returns a random point (x, y) that is within the given bounds ((x1, y1), (x2, y2))
+    """
+
+    x = randint(bounds[0][0], bounds[1][0])
+    y = randint(bounds[0][1], bounds[1][1])
+
+    return (x, y)
